# GenericFloatMetric

A generic float metric. Its meaning is described by its name. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name of the metric. Typically only one metric of a given name will be provided, but uniqueness is not guaranteed. The name describes the meaning of the value | 
**value** | **float** | The value of the metric. The meaning of this value depends on the name. | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


